@@ -1,4 +1,5 @@
 ##Note this has identical functionality to the function "convhulln" in the package "geometry"
 "convhullnew" <-
-function (p, options = " ") 
+function (p, options = "Qt" )
+  ## Default triangulated output
 .Call("convhullnew", as.matrix(p), as.character(options),PACKAGE="LogConcDEAD")
